@@ -1,6 +1,6 @@
 /* BLINKENLIGHTS PROXY
- * version 0.92 date 2004-04-07
- * Copyright (C) 2003 1stein <1stein@schuermans.info>
+ * version 0.93 date 2004-04-26
+ * Copyright (C) 2003-2004 1stein <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
 
@@ -26,7 +26,12 @@
 #include "output.h"
 #include "tools.h"
 
-#define BL_PROXY_VERSION_STR "version 0.92 date 2004-04-07"
+#define BL_PROXY_VERSION_STR "version 0.93 date 2004-04-26"
+
+//default listen address for control connections
+#define listen_af "in"
+#define listen_addr "127.0.0.1"
+#define listen_port "4200"
 
 //maximum number of control connections
 #define ctrl_conn_cnt_max 5
@@ -137,9 +142,9 @@ int main( int arg_cnt, char * * args )
   p_output_filename = output_filename;
 
   //parse parameters
-  p_af = "in";
-  p_addr = "127.0.0.1";
-  p_port = "4200";
+  p_af = listen_af;
+  p_addr = listen_addr;
+  p_port = listen_port;
   local_input = 0;
   quiet = 0;
   param_err = 0;
@@ -185,7 +190,7 @@ int main( int arg_cnt, char * * args )
     printf( "\n"
             "BLINKENLIGHTS PROXY\n"
             BL_PROXY_VERSION_STR"\n"
-            "Copyright (C) 2003 1stein <1stein@schuermans.info>\n"
+            "Copyright (C) 2003-2004 1stein <1stein@schuermans.info>\n"
             "Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html\n"
 	    "\n" );
 
@@ -197,9 +202,9 @@ int main( int arg_cnt, char * * args )
             "\n"
             "options: \"-i <input-file>\" (defaults to \"%s\")\n"
             "         \"-o <output-file>\" (defaults to \"%s\")\n"
-            "         \"-f <listen-address-family>\" (\"in\" or \"in6\", defaults to \"in\")\n"
-            "         \"-a <listen-address>\" (defaults to \"127.0.0.1\")\n"
-            "         \"-p <listen-port>\" (defaults to \"2323\")\n"
+            "         \"-f <listen-address-family>\" (\"in\" or \"in6\", defaults to \""listen_af"\")\n"
+            "         \"-a <listen-address>\" (defaults to \""listen_addr"\")\n"
+            "         \"-p <listen-port>\" (defaults to \""listen_port"\")\n"
             "         \"-l\" enable local command input\n"
             "         \"-q\" quiet mode\n"
             "\n",
